@@ -1,6 +1,7 @@
 from flask import request
 from ..database_util import User
 from functools import wraps
+import datetime
 
 def get_user(username):
     """
@@ -12,7 +13,11 @@ def get_user(username):
     return User.query.filter_by(username=username).first()
 
 def authorized(user, token):
-    return user.token == token if user else False
+    if user:
+        return user.token == token and \
+             user.token_generated_date.date() + datetime.timedelta(days=3) > datetime.date.today()
+    else:
+        return False
 
 def auth_required(function):
     @wraps(function)
@@ -23,14 +28,11 @@ def auth_required(function):
                         auth failed message
         """
         try:
-            # username = request.cookies.get('username')
-            # password = request.cookies.get('password')
-            token = request.cookies.get('token')
-            print(token)
+            print("inside of try")
+            token = request.json['token']
             user = User.query.filter_by(token=token).first()
-            print(user)
             if user is not None:
-                return function(token, *args, **kwargs) if authorized(user, token) else "Auth failed"
+                return function(token, *args, **kwargs) if authorized(user, token) else "Auth failed, maybe you token is expired, try login again"
         except Exception as e:
             return "Auth error: " + str(e)
     return decorated
